@@ -87,26 +87,31 @@ class NaPoleonBinanceFutureBot(object):
         minBCH = 20 / BCH
         return usdt_balance, balance, ticker_data, minBTC, minETH, minLTC, minXRP, minEOS, minTRX, minBCH
 
-    def make_sure_positions_changed(self, positions, sleeping_time = 30):
+    def make_sure_positions_changed(self, positions, sleeping_time = 45):
         position_changed = False
+        counter = 1
         while not  position_changed:
-            print('updating positions '+str(positions))
+            if counter>1:
+                print(f'position not reached : reupdating positions {positions}')
+            self.cancel_all_order()
             position_changed = self.change_position(positions)
             # Prints the current time with a five second difference
+            print(f'waiting for the oder to be filled {sleeping_time}')
             time.sleep(sleeping_time)
+            counter = counter+1
 
     def update_position(self, pair, pair_signal):
+        print(f'entering the global update position for {pair} and signals {pair_signal}')
+        print('canceling all orders')
         positions ={}
         if pair == 'BTCUSDT':
             positions['BTC']=pair_signal
             self.make_sure_positions_changed(positions)
         else :
-            print('pair not handled for the moment '+pair)
-
-
+            print(f'pair not handled for the moment {pair}')
 
     def change_position(self, positions):
-        print('incoming positions to hodl ',str(positions))
+        print(f'incoming positions to hodl {positions}')
         usdt_balance, balance, ticker_data, minBTC, minETH, minLTC, minXRP, minEOS, minTRX, minBCH = self.get_balance()
         ETH = float(ticker_data['ETH/USDT']['info']['lastPrice'])
         BTC = float(ticker_data['BTC/USDT']['info']['lastPrice'])
