@@ -1052,12 +1052,14 @@ class RealTimeSignalEnsemblingParalleLauncher():
             new_data_sig = np.hstack((self.day_np[-1,:].reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
         else:
             new_data_sig = np.hstack((self.day_np.reshape(1, len(self.generic_columns)), new_data_sig.reshape(1, len(new_data_sig))))
-        #print('new daily data signal')
-        #print(new_data_sig)
+        print('new daily data signal')
+        print(new_data_sig)
         if self.day_signal_np is None:
             self.day_signal_np = new_data_sig
         else:
             self.day_signal_np = np.vstack((self.day_signal_np, new_data_sig))
+
+        print(f'day signal shape {self.day_signal_np.shape}')
         if len(self.day_signal_np.shape)>1 and len(self.day_signal_np)>3:
             #print('last three daily signals')
             #print(self.day_signal_np[-3:])
